@@ -10,7 +10,7 @@ use Carp();
 
 use base qw(Exporter);
 our @EXPORT_OK = qw(is_holiday holidays);
-our $VERSION   = '0.16';
+our $VERSION   = '0.17';
 
 my %cached;
 
@@ -1343,7 +1343,7 @@ Date::Holidays::AU - Determine Australian Public Holidays
 
 =head1 VERSION
  
-Version 0.16
+Version 0.17
 
 =head1 SYNOPSIS
 
@@ -1351,7 +1351,7 @@ Version 0.16
   my ($year, $month, $day) = (localtime)[ 5, 4, 3 ];
   $year  += 1900;
   $month += 1;
-  my ($state) = 'VIC';
+  my $state = 'VIC';
   print "Excellent\n" if is_holiday( $year, $month, $day, $state );
 
 =head1 DESCRIPTION
@@ -1397,7 +1397,7 @@ modules from the standard Perl distribution.
 
 =head1 CONFIGURATION AND ENVIRONMENT
  
-Archive::Har requires no configuration files or environment variables.  
+Date::Holidays::AU requires no configuration files or environment variables.  
 
 =head1 INCOMPATIBILITIES
  
